# SignalR
    
> see https://aka.ms/autorest

This is the AutoRest configuration file for SignalR.



---
## Getting Started 
To build the SDK for SignalR, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information 
These are the global settings for the SignalR API.

``` yaml
openapi-type: arm
tag: package-2018-03-01-preview
```


### Tag: package-2018-03-01-preview

These settings apply only when `--tag=package-2018-03-01-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-03-01-preview'
input-file:
- Microsoft.SignalRService/preview/2018-03-01-preview/signalr.json
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_signalr']
```


## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.signalr
  package-name: azure-mgmt-signalr
  package-version: 0.1.0
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-signalr/azure/mgmt/signalr
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-signalr
```


## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  namespace: signalr
  clear-output-folder: true
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2018-03-01-preview
```

### Tag: package-2018-03-01-preview and go

These settings apply only when `--tag=package-2018-03-01-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2018-03-01-preview' && $(go)
output-folder: $(go-sdk-folder)/services/preview/signalr/mgmt/2018-03-01-preview/signalr
```

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.signalr
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-signalr
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-03-01-preview
```

### Tag: package-2018-03-01-preview and java

These settings apply only when `--tag=package-2018-03-01-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-03-01-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.signalr.v2018_03_01_preview
  output-folder: $(azure-libraries-for-java-folder)/signalr/resource-manager/v2018_03_01_preview
regenerate-manager: true
generate-interface: true
```

## C# 

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  # last generated with AutoRest.0.17.3
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.SignalR
  output-folder: $(csharp-sdks-folder)/SignalR/Management.SignalR/Generated
  clear-output-folder: true
```
